@@ -1,12 +1,12 @@
-#' Gets the feature specifications form the model
+#' Get feature specifications from the model
 #'
 #' @inheritParams explain
 #' @keywords internal
 get_feature_specs <- function(get_model_specs, model) {
-  # Checks that get_model_specs is a proper function (R + py)
-  # Extracts natively supported functions for get_model_specs if exists and not passed (R only)
-  # Apply get_model_specs on model and checks that it provides the right output format (R and py)
-  # Returns the feature_specs (R and py)
+  # Check that get_model_specs is a proper function (R + Python)
+  # Extract natively supported functions for get_model_specs if they exist and are not passed (R only)
+  # Apply get_model_specs to model and check that it provides the right output format (R and Python)
+  # Return feature_specs (R and py)
 
   model_class <- NULL # due to NSE
 
@@ -16,7 +16,7 @@ get_feature_specs <- function(get_model_specs, model) {
   if (!is.function(get_model_specs) &&
     !is.null(get_model_specs) &&
     !is.na(get_model_specs)) {
-    cli::cli_abort("`get_model_specs` must be NULL, NA or a function.")
+    cli::cli_abort("`get_model_specs` must be NULL, NA, or a function.")
     # NA is used to avoid using internally defined get_model_specs where this is
     # defined and not valid for the specified model
   }
@@ -24,7 +24,7 @@ get_feature_specs <- function(get_model_specs, model) {
   supported_models <- get_supported_models()
 
 
-  # Get native get_model_specs if not passed and exists
+  # Get native get_model_specs if not passed and available
   if (is.null(get_model_specs)) {
     native_func_available <- supported_models[get_model_specs == TRUE, model_class0 %in% model_class]
     if (native_func_available) {
@@ -34,13 +34,13 @@ get_feature_specs <- function(get_model_specs, model) {
     }
   }
 
-  # Get the feature_specs from the model object by get_model_specs(model)
+  # Get feature_specs from the model object by get_model_specs(model)
   if (is.function(get_model_specs)) {
     # Tests the get_model_specs function
     feature_specs <- tryCatch(get_model_specs(model), error = errorfun)
     if (class(feature_specs)[1] == "error") {
       cli::cli_abort(paste0(
-        "The `get_model_specs` function of class `", model_class0, "` is invalid. ",
+        "The `get_model_specs` function for class `", model_class0, "` is invalid. ",
         "See the 'Advanced usage' section of ",
         "{.vignette shapr::general_usage} vignette ",
         "for more information on running shapr with custom models. ",
@@ -55,8 +55,8 @@ get_feature_specs <- function(get_model_specs, model) {
       all(names(feature_specs) == c("labels", "classes", "factor_levels")))) {
       cli::cli_abort(
         paste0(
-          "The `get_model_specs` function of class `", model_class0,
-          "` does not return a list of length 3 with elements \"labels\", \"classes\", \"factor_levels\". ",
+          "The `get_model_specs` function for class `", model_class0,
+          "` does not return a list of length 3 with elements \"labels\", \"classes\", and \"factor_levels\". ",
           "See the 'Advanced usage' section of ",
           "{.vignette shapr::general_usage} vignette ",
           "for more information on running shapr with custom models and the required output format of get_model_specs."
