@@ -1,4 +1,4 @@
-#' Plot of the Shapley value explanations
+#' Plot of the Shapley Value Explanations
 #'
 #' @description Plots the individual prediction explanations.
 #'
@@ -17,6 +17,14 @@
 #' @param digits Integer.
 #' Number of significant digits to use in the feature description.
 #' Applicable for `plot_type` `"bar"` and `"waterfall"`
+#' @param print_ggplot Logical.
+#' Whether to print the created `ggplot` object once it is returned.
+#' The default is `TRUE` which ensures the plot is always displayed also in loops, functions, when sourcing a script,
+#' and when assigning the output to a variable like `p <- plot.shapr(...)`.
+#' See [ggplot2::print.ggplot()] for more details.
+#' If you wish to further modify the returned `ggplot` object outside of `plot.shapr`,
+#' we recommend setting `print_ggplot = FALSE` to avoid force printing.
+#' See the examples for a practical use case.
 #' @param bar_plot_phi0 Logical.
 #' Whether to include `phi0` in the plot for  `plot_type = "bar"`.
 #' @param index_x_explain Integer vector.
@@ -169,6 +177,15 @@
 #'     plot(x, plot_type = "scatter")
 #'     plot(x, plot_type = "beeswarm")
 #'   }
+#'
+#'   # Example of further modification of the output from plot.shapr
+#'   plt = plot(x, index_x_explain = 1:4, print_ggplot = FALSE) # Stores ggplot object without printing
+#'
+#'   # Displays the modified ggplot object
+#'   plt +
+#'     ggplot2::ggtitle("My custom title") +
+#'     ggplot2::ylab("Variable influence") +
+#'     ggplot2::xlab("Variable")
 #' }
 #' }
 #'
@@ -176,6 +193,7 @@
 plot.shapr <- function(x,
                        plot_type = "bar",
                        digits = 3,
+                       print_ggplot = TRUE,
                        index_x_explain = NULL,
                        top_k_features = NULL,
                        col = NULL,
@@ -210,8 +228,8 @@ plot.shapr <- function(x,
   # For group-wise Shapley values, we check if we are to take the mean over grouped features
   if (is_groupwise) {
     if (is.na(include_group_feature_means) ||
-      !is.logical(include_group_feature_means) ||
-      length(include_group_feature_means) > 1) {
+        !is.logical(include_group_feature_means) ||
+        length(include_group_feature_means) > 1) {
       cli::cli_abort("`include_group_feature_means` must be single logical.")
     }
     if (!include_group_feature_means && plot_type %in% c("scatter", "beeswarm")) {
@@ -285,8 +303,8 @@ plot.shapr <- function(x,
     factor_features <- shap_names[factor_features]
 
     dt_feature_vals_long <- suppressWarnings(data.table::melt(dt_feature_vals,
-      id.vars = "id",
-      value.name = "feature_value"
+                                                              id.vars = "id",
+                                                              value.name = "feature_value"
     ))
     # this gives a warning because none-values are NA...
     dt_plot <- merge(dt_plot, dt_feature_vals_long, by = c("id", "variable"))
@@ -298,12 +316,12 @@ plot.shapr <- function(x,
     gg <- make_scatter_plot(dt_plot, scatter_features, scatter_hist, col, factor_features)
   } else if (plot_type == "beeswarm") {
     gg <- make_beeswarm_plot(dt_plot,
-      col,
-      index_x_explain,
-      x,
-      factor_features,
-      beeswarm_cex = beeswarm_cex,
-      ...
+                             col,
+                             index_x_explain,
+                             x,
+                             factor_features,
+                             beeswarm_cex = beeswarm_cex,
+                             ...
     )
   } else { # if bar or waterfall plot
     # Only plot the desired observations
@@ -355,7 +373,12 @@ plot.shapr <- function(x,
       gg <- make_waterfall_plot(dt_plot, expected, col, digits, bar_plot_order, breaks, desc_labels)
     }
   }
-  return(gg)
+
+  if (isTRUE(print_ggplot)) {
+    return(print(gg)) # Return the figure with force display
+  } else {
+    return(gg) # Return the figure without force display
+  }
 }
 
 get_n_breaks <- function(dt_plot, feature_name) {
@@ -619,8 +642,8 @@ make_beeswarm_plot <- function(dt_plot,
   # of obs. feature value.
   # The feature values are scaled wrt the training data
   dt_plot[feature_value <= max & feature_value >= min,
-    feature_value_scaled := (feature_value - min) / (max - min),
-    by = variable
+          feature_value_scaled := (feature_value - min) / (max - min),
+          by = variable
   ]
   dt_plot[feature_value > max, feature_value_scaled := 1]
   dt_plot[feature_value < min, feature_value_scaled := 0]
@@ -696,7 +719,7 @@ make_bar_plot <- function(dt_plot, bar_plot_phi0, col, breaks, desc_labels) {
   dt_plot[positive == FALSE & y_text_bar == 0, y_text_bar := ifelse(phi < 0, phi, 0)]
 
   dt_plot[, text_color_bar := ifelse(abs(phi) > max(abs(phi)) / 8, "white", ifelse(sign == "Increases",
-    col[1], col[2]
+                                                                                   col[1], col[2]
   )), by = id]
   if (bar_plot_phi0) {
     text_color_bar <- dt_plot[, text_color_bar]
@@ -752,33 +775,33 @@ make_waterfall_plot <- function(dt_plot,
   # waterfall plotting helpers
   if (bar_plot_order == "largest_first" || bar_plot_order == "original") {
     dt_plot[, y_text := ifelse(abs(phi) < abs(min(start, end) - max(start, end)) / 8,
-      ifelse(expected < pred, ifelse(end > start, end, start),
-        ifelse(end < start, end, start)
-      ),
-      start + (end - start) / 2
+                               ifelse(expected < pred, ifelse(end > start, end, start),
+                                      ifelse(end < start, end, start)
+                               ),
+                               start + (end - start) / 2
     ), by = id]
   } else if (bar_plot_order == "smallest_first") {
     dt_plot[, y_text := ifelse(abs(phi) < abs(min(start, end) - max(start, end)) / 8,
-      ifelse(expected > pred, ifelse(end > start, end, start),
-        ifelse(end < start, end, start)
-      ),
-      start + (end - start) / 2
+                               ifelse(expected > pred, ifelse(end > start, end, start),
+                                      ifelse(end < start, end, start)
+                               ),
+                               start + (end - start) / 2
     ), by = id]
   }
 
   dt_plot[, text_color := ifelse(abs(phi) < abs(min(start, end) - max(start, end)) / 8,
-    ifelse(sign == "Increases", col[1], col[2]),
-    "white"
+                                 ifelse(sign == "Increases", col[1], col[2]),
+                                 "white"
   ), by = id]
   text_color <- dt_plot[variable != "none", text_color]
 
   if (bar_plot_order == "largest_first" || bar_plot_order == "original") {
     dt_plot[, hjust_text := ifelse(abs(phi) < abs(min(start, end) - max(start, end)) / 8,
-      ifelse(expected > pred, 1, 0), 0.5
+                                   ifelse(expected > pred, 1, 0), 0.5
     ), by = id]
   } else if (bar_plot_order == "smallest_first") {
     dt_plot[, hjust_text := ifelse(abs(phi) < abs(min(start, end) - max(start, end)) / 8,
-      ifelse(expected > pred, 0, 1), 0.5
+                                   ifelse(expected > pred, 0, 1), 0.5
     ), by = id]
   }
 
@@ -801,11 +824,11 @@ make_waterfall_plot <- function(dt_plot,
     ggplot2::scale_fill_manual(values = col, drop = TRUE) +
     ggplot2::scale_x_discrete(breaks = breaks, labels = desc_labels) +
     ggplot2::geom_segment(ggplot2::aes(x = -Inf, xend = max(rank_waterfall) + 0.8, y = pred, yend = pred),
-      linetype = "dotted", col = "grey30", linewidth = 0.25
+                          linetype = "dotted", col = "grey30", linewidth = 0.25
     ) +
     ggplot2::coord_flip(clip = "off", xlim = c(0.5, ifelse(N_features + N_features * 0.11 < N_features + 0.5,
-      N_features + 0.5,
-      N_features + N_features * 0.11
+                                                           N_features + 0.5,
+                                                           N_features + N_features * 0.11
     ))) +
     ggplot2::labs(
       y = "Prediction",
@@ -814,7 +837,7 @@ make_waterfall_plot <- function(dt_plot,
       title = "Shapley value prediction explanation"
     ) +
     ggplot2::geom_rect(ggplot2::aes(xmin = rank_waterfall - 0.3, xmax = rank_waterfall + 0.3, ymin = end, ymax = start),
-      show.legend = NA
+                       show.legend = NA
     ) +
     ggplot2::geom_segment(
       x = -Inf, xend = 1.3, y = expected, yend = expected,
@@ -894,9 +917,13 @@ make_waterfall_plot <- function(dt_plot,
 #' If `plot_type` is a vector of one or several of "overall", "comb", and "explicand", then the associated plots are
 #' created.
 #'
+#' @details Note that in contrast to [plot.shapr()], [plot_MSEv_eval_crit()] always just returns the ggplot objects,
+#' i.e. no force displaying through [ggplot2::print.ggplot()].
+#'
 #' @return Either a single [ggplot2::ggplot()] object of the MSEv criterion when `plot_type = "overall"`, or a list
 #' of [ggplot2::ggplot()] objects based on the `plot_type` parameter.
 #'
+#'
 #' @export
 #' @examples
 #' \donttest{
@@ -1248,20 +1275,20 @@ MSEv_extract_MSEv_values <- function(explanation_list,
 
   # The overall MSEv criterion
   MSEv <- rbindlist(lapply(explanation_list, function(explanation) explanation$MSEv$MSEv),
-    use.names = TRUE, idcol = "Method"
+                    use.names = TRUE, idcol = "Method"
   )
   MSEv$Method <- factor(MSEv$Method, levels = names(explanation_list))
 
   # The MSEv evaluation criterion for each explicand.
   MSEv_explicand <- rbindlist(lapply(explanation_list, function(explanation) explanation$MSEv$MSEv_explicand),
-    use.names = TRUE, idcol = "Method"
+                              use.names = TRUE, idcol = "Method"
   )
   MSEv_explicand$id <- factor(MSEv_explicand$id)
   MSEv_explicand$Method <- factor(MSEv_explicand$Method, levels = names(explanation_list))
 
   # The MSEv evaluation criterion for each coalition.
   MSEv_coalition <- rbindlist(lapply(explanation_list, function(explanation) explanation$MSEv$MSEv_coalition),
-    use.names = TRUE, idcol = "Method"
+                              use.names = TRUE, idcol = "Method"
   )
   MSEv_coalition$id_coalition <- factor(MSEv_coalition$id_coalition)
   MSEv_coalition$Method <- factor(MSEv_coalition$Method, levels = names(explanation_list))
@@ -1293,7 +1320,7 @@ make_MSEv_bar_plot <- function(MSEv_dt,
       x = "Method",
       y = bquote(MSE[v]),
       title = bquote(MSE[v] ~ "criterion averaged over the" ~ .(n_coalitions) ~
-        "coalitions and" ~ .(n_explain) ~ "explicands")
+                       "coalitions and" ~ .(n_explain) ~ "explicands")
     )
 
   if (!is.null(tfrac)) {
@@ -1301,8 +1328,8 @@ make_MSEv_bar_plot <- function(MSEv_dt,
 
     MSEv_bar <- MSEv_bar +
       ggplot2::labs(title = bquote(MSE[v] ~ "criterion averaged over the" ~ .(n_coalitions) ~
-        "coalitions and" ~ .(n_explain) ~ "explicands with" ~
-        .(CI_level * 100) * "% CI")) +
+                                     "coalitions and" ~ .(n_explain) ~ "explicands with" ~
+                                     .(CI_level * 100) * "% CI")) +
       ggplot2::geom_errorbar(
         position = ggplot2::position_dodge(geom_col_width),
         width = 0.25,
@@ -1328,7 +1355,7 @@ make_MSEv_explicand_plots <- function(MSEv_explicand_dt,
       x = "index_x_explain",
       y = bquote(MSE[v] ~ "(explicand)"),
       title = bquote(MSE[v] ~ "criterion averaged over the" ~ .(n_coalitions) ~
-        "coalitions for each explicand")
+                       "coalitions for each explicand")
     )
 
   MSEv_explicand_bar <-
@@ -1364,7 +1391,7 @@ make_MSEv_coalition_plots <- function(MSEv_coalition_dt,
       x = "id_coalition",
       y = bquote(MSE[v] ~ "(coalition)"),
       title = bquote(MSE[v] ~ "criterion averaged over the" ~ .(n_explain) ~
-        "explicands for each coalition")
+                       "explicands for each coalition")
     )
 
   MSEv_coalition_bar <-
@@ -1381,7 +1408,7 @@ make_MSEv_coalition_plots <- function(MSEv_coalition_dt,
     MSEv_coalition_bar <-
       MSEv_coalition_bar +
       ggplot2::labs(title = bquote(MSE[v] ~ "criterion averaged over the" ~ .(n_explain) ~
-        "explicands for each coalition with" ~ .(CI_level * 100) * "% CI")) +
+                                     "explicands for each coalition with" ~ .(CI_level * 100) * "% CI")) +
       ggplot2::geom_errorbar(
         position = ggplot2::position_dodge(geom_col_width),
         width = 0.25,
@@ -1406,7 +1433,7 @@ make_MSEv_coalition_plots <- function(MSEv_coalition_dt,
   ))
 }
 
-#' Shapley value bar plots for several explanation objects
+#' Shapley Value Bar Plots for Several Explanation Objects
 #'
 #' @description
 #' Make plots to visualize and compare the estimated Shapley values for a list of
@@ -1546,16 +1573,20 @@ make_MSEv_coalition_plots <- function(MSEv_coalition_dt,
 #'   plot_SV_several_approaches(explanation_list)
 #'
 #'   # We can change the number of columns in the grid of plots and add other visual alterations
+#'   # Set `print_ggplot = FALSE` to avoid force displaying the ggplot object before the modifications
+#'   # outside plot_SV_several_approaches()
+#'
 #'   plot_SV_several_approaches(explanation_list,
 #'     facet_ncol = 3,
 #'     facet_scales = "free_y",
 #'     add_zero_line = TRUE,
 #'     digits = 2,
 #'     brewer_palette = "Paired",
-#'     geom_col_width = 0.6
+#'     geom_col_width = 0.6,
+#'     print_ggplot = FALSE
 #'   ) +
 #'     ggplot2::theme_minimal() +
-#'     ggplot2::theme(legend.position = "bottom", plot.title = ggplot2::element_text(size = 0))
+#'     ggplot2::theme(legend.position = "bottom", plot.title = ggplot2::element_text(size = 10))
 #'
 #'
 #'   # We can specify which explicands to plot to get less chaotic plots and make the bars vertical
@@ -1580,6 +1611,7 @@ make_MSEv_coalition_plots <- function(MSEv_coalition_dt,
 #'     only_these_features = c("Temp", "Solar.R"),
 #'     plot_phi0 = TRUE
 #'   )
+#'
 #' }
 #' }
 #'
@@ -1590,6 +1622,7 @@ plot_SV_several_approaches <- function(explanation_list,
                                        only_these_features = NULL,
                                        plot_phi0 = FALSE,
                                        digits = 4,
+                                       print_ggplot = TRUE,
                                        add_zero_line = FALSE,
                                        axis_labels_n_dodge = NULL,
                                        axis_labels_rotate_angle = NULL,
@@ -1724,8 +1757,11 @@ plot_SV_several_approaches <- function(explanation_list,
   }
   if (horizontal_bars) figure <- figure + ggplot2::coord_flip()
 
-  # Return the figure
-  return(figure)
+  if (isTRUE(print_ggplot)) {
+    return(print(figure))   # Return the figure with force display
+  } else {
+    return(figure) # Return the figure without force display
+  }
 }
 
 
@@ -1915,9 +1951,9 @@ create_feature_descriptions_dt <- function(explanation_list,
   # Converting and melting the explicands
   dt_desc <- data.table::as.data.table(cbind(none = "None", desc_mat))
   dt_desc_long <- data.table::melt(dt_desc[, .id := index_explicands],
-    id.vars = ".id",
-    variable.name = ".feature",
-    value.name = ".description"
+                                   id.vars = ".id",
+                                   variable.name = ".feature",
+                                   value.name = ".description"
   )
 
   # Make the description into an ordered factor such that the features in the
@@ -1939,9 +1975,9 @@ create_Shapley_value_figure_dt <- function(dt_Shapley_values,
 
   # Melt the data.table from a wide to long format
   dt_Shapley_values_long <- data.table::melt(dt_Shapley_values,
-    id.vars = c(".id", ".pred", ".method"),
-    variable.name = ".feature",
-    value.name = ".phi"
+                                             id.vars = c(".id", ".pred", ".method"),
+                                             variable.name = ".feature",
+                                             value.name = ".phi"
   )
   dt_Shapley_values_long$.feature <- as.ordered(dt_Shapley_values_long$.feature)
 
@@ -1951,23 +1987,23 @@ create_Shapley_value_figure_dt <- function(dt_Shapley_values,
 
   # Make the .id column into an ordered column
   dt_Shapley_values_long$.id <- factor(dt_Shapley_values_long$.id,
-    levels = unique(dt_Shapley_values_long$.id),
-    ordered = TRUE
+                                       levels = unique(dt_Shapley_values_long$.id),
+                                       ordered = TRUE
   )
 
   # Adding header for each individual plot
   dt_Shapley_values_long[, .header := paste0("id: ", .id, ", pred = ", format(.pred, digits = digits))]
   dt_Shapley_values_long$.header <- factor(dt_Shapley_values_long$.header,
-    levels = unique(dt_Shapley_values_long$.header),
-    ordered = TRUE
+                                           levels = unique(dt_Shapley_values_long$.header),
+                                           ordered = TRUE
   )
 
   # If flip coordinates, then we need to change the order of the levels such that the order
   # of the bars in the figure match the order in the legend.
   if (horizontal_bars) {
     dt_Shapley_values_long$.method <- factor(dt_Shapley_values_long$.method,
-      levels = rev(levels(dt_Shapley_values_long$.method)),
-      ordered = TRUE
+                                             levels = rev(levels(dt_Shapley_values_long$.method)),
+                                             ordered = TRUE
     )
     breaks <- rev(levels(dt_Shapley_values_long$.method))
   } else {
